@@ -9,16 +9,20 @@ from bs4 import BeautifulSoup
 def recordupload(torrent_file,file1,String_url,downloadurl):
     logger.info('正在记录发布的资源到'+torrent_file)
     if not os.path.exists(torrent_file):
-        if 'win' in sys.platform:
-            f = open(torrent_file,'w+',encoding='utf-8')
+        if 'win32' in sys.platform:
+            f = open(torrent_file,'w+',encoding='utf-8-sig',errors='ignore')
         else:
             f = open(torrent_file,'w+',encoding='utf-8-sig')
 
         f.write('中文名,集数,发布日期,资源链接,资源下载链接\n0\n')
         f.close()
 
-    with open(torrent_file, 'r') as f1:
-        list1 = f1.readlines()
+    if 'win32' in sys.platform:
+        with open(torrent_file, 'r',encoding='utf-8-sig',errors='ignore') as f1:
+            list1 = f1.readlines()
+    else:
+        with open(torrent_file, 'r') as f1:
+            list1 = f1.readlines()
     while list1[-1].strip()=='':
         a=list1.pop(-1)
         del(a)
@@ -49,8 +53,8 @@ def recordupload(torrent_file,file1,String_url,downloadurl):
     logger.debug(newstr)
 
     filestr=filestr+newstr+str(num+1)+'\n'
-    if 'win' in sys.platform:
-        f = open(torrent_file,'w+',encoding='utf-8')
+    if 'win32' in sys.platform:
+        f = open(torrent_file,'w+',encoding='utf-8-sig',errors='ignore')
     else:
         f = open(torrent_file,'w+',encoding='utf-8-sig')
     f.write(filestr)
